@@ -4,7 +4,7 @@ import { Op } from 'sequelize';
 import { ScheduledTask } from '@tamanu/shared/tasks';
 import { log } from '@tamanu/shared/services/logging';
 import { sleepAsync } from '@tamanu/utils/sleepAsync';
-import { InvalidConfigError } from '@tamanu/shared/errors';
+import { InvalidConfigError } from '.';
 
 export class DeceasedPatientDischarger extends ScheduledTask {
   getName() {
